@@ -338,21 +338,21 @@ gnm_cell_set_array_formula_cb (GnmSheetRange const *sr, GnmExprTop const  *texpr
 	sheet_region_queue_recalc (sr->sheet, &sr->range);
 	gnm_expr_top_ref (texpr);
 	gnm_cell_set_array_formula (sr->sheet,
-				    sr->range.start.col, sr->range.start.row, 
+				    sr->range.start.col, sr->range.start.row,
 				    sr->range.end.col,   sr->range.end.row,
 				    texpr);
 	sheet_region_queue_recalc (sr->sheet, &sr->range);
 	sheet_flag_status_update_range (sr->sheet, &sr->range);
 	sheet_queue_respan (sr->sheet, sr->range.start.row, sr->range.end.row);
-} 
+}
 
 GOUndo *
 gnm_cell_set_array_formula_undo (GnmSheetRange *sr, GnmExprTop const  *texpr)
 {
 	gnm_expr_top_ref (texpr);
-	return go_undo_binary_new (sr, (gpointer)texpr, 
-				   (GOUndoBinaryFunc) gnm_cell_set_array_formula_cb, 
-				   (GFreeFunc) gnm_sheet_range_free, 
+	return go_undo_binary_new (sr, (gpointer)texpr,
+				   (GOUndoBinaryFunc) gnm_cell_set_array_formula_cb,
+				   (GFreeFunc) gnm_sheet_range_free,
 				   (GFreeFunc) gnm_expr_top_unref);
 }
 
@@ -782,6 +782,28 @@ gnm_cell_set_format (GnmCell *cell, char const *format)
 	sheet_style_apply_range (cell->base.sheet, &r, mstyle);
 }
 
+static GnmValue *
+cb_set_array_value (GnmCellIter const *iter, gpointer user)
+{
+	GnmValue const *value = user;
+	GnmCell *cell = iter->cell;
+	int x, y;
+
+	/* Clipboard cells, e.g., are not attached to a sheet.  */
+	if (gnm_cell_expr_is_linked (cell))
+		dependent_unlink (GNM_CELL_TO_DEP (cell));
+
+	if (!gnm_expr_top_is_array_elem (cell->base.texpr, &x, &y))
+		return NULL;
+
+	gnm_expr_top_unref (cell->base.texpr);
+	cell->base.texpr = NULL;
+	value_release (cell->value);
+	cell->value = value_dup (value_area_get_x_y (value, x, y, NULL));
+
+	return NULL;
+}
+
 /**
  * gnm_cell_convert_expr_to_value : drops the expression keeps its value.  Then uses the formatted
  *      result as if that had been entered.
@@ -793,12 +815,12 @@ gnm_cell_set_format (GnmCell *cell, char const *format)
  *
  * WARNING : This is an internal routine that does not queue redraws,
  *           does not auto-resize, and does not calculate spans.
- *
- * NOTE : This DOES NOT check for array partitioning.
  */
 void
 gnm_cell_convert_expr_to_value (GnmCell *cell)
 {
+	GnmExprArrayCorner const *array;
+
 	g_return_if_fail (cell != NULL);
 	g_return_if_fail (gnm_cell_has_expr (cell));
 
@@ -806,6 +828,18 @@ gnm_cell_convert_expr_to_value (GnmCell *cell)
 	if (gnm_cell_expr_is_linked (cell))
 		dependent_unlink (GNM_CELL_TO_DEP (cell));
 
+	array = gnm_expr_top_get_array_corner (cell->base.texpr);
+	if (array) {
+		sheet_foreach_cell_in_range (cell->base.sheet, CELL_ITER_ALL,
+					     cell->pos.col, cell->pos.row,
+					     cell->pos.col + array->cols - 1,
+					     cell->pos.row + array->rows - 1,
+					     cb_set_array_value,
+					     array->value);
+	} else {
+		g_return_if_fail (!gnm_cell_is_array (cell));
+	}
+
 	gnm_expr_top_unref (cell->base.texpr);
 	cell->base.texpr = NULL;
 }
