@@ -48,6 +48,8 @@
 
 #include <string.h>
 
+#include <dead-kittens.h>
+
 #define DOC_METADATA_KEY "dialog-doc-metadata"
 
 enum {
@@ -609,7 +611,7 @@ dialog_doc_metadata_set_gsf_prop (DialogDocMetaData *state,
 
 	if (val_type != G_TYPE_INVALID) {
 		GValue     *doc_prop_value;
-		
+
 		/* Create a new Value */
 		doc_prop_value = g_new0 (GValue, 1);
 
@@ -1567,9 +1569,8 @@ dialog_doc_meta_data_add_item (DialogDocMetaData *state, char const *page_name,
 	GdkPixbuf * icon = NULL;
 
 	if (icon_name != NULL)
-		icon = gtk_widget_render_icon (state->dialog, icon_name,
-					       GTK_ICON_SIZE_MENU,
-					       DOC_METADATA_KEY);
+		icon = gtk_widget_render_icon_pixbuf (state->dialog, icon_name,
+					       GTK_ICON_SIZE_MENU);
 	if ((parent_path != NULL) && gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (state->store),
 									  &parent, parent_path))
 		gtk_tree_store_append (state->store, &iter, &parent);
