@@ -87,9 +87,8 @@ dialog_pref_add_item (PrefState *state, char const *page_name,
 	GdkPixbuf * icon = NULL;
 
 	if (icon_name != NULL)
-		icon = gtk_widget_render_icon (state->dialog, icon_name,
-					       GTK_ICON_SIZE_MENU,
-					       "Gnumeric-Preference-Dialog");
+		icon = gtk_widget_render_icon_pixbuf (state->dialog, icon_name,
+					       GTK_ICON_SIZE_MENU);
 	if ((parent_path != NULL) && gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (state->store),
 									  &parent, parent_path))
 		gtk_tree_store_append (state->store, &iter, &parent);
@@ -275,7 +274,8 @@ enum_pref_create_widget (GOConfNode *node, GtkWidget *table,
 			 gint row, GType enum_type,
 			 enum_conf_setter_t setter,
 			 enum_conf_getter_t getter,
-			 gchar const *default_label)
+			 gchar const *default_label,
+                         char const *(*label_getter)(int))
 {
 	unsigned int	 i;
 	GtkTreeIter	 iter;
@@ -290,7 +290,7 @@ enum_pref_create_widget (GOConfNode *node, GtkWidget *table,
 	for (i = 0; i < enum_class->n_values ; i++) {
 		gtk_list_store_append (model, &iter);
 		gtk_list_store_set (model, &iter,
-			0,	enum_class->values[i].value_nick,
+			0,	label_getter ((int) enum_class->values[i].value),
 			1,	enum_class->values + i,
 			-1);
 		if (enum_class->values[i].value == current)
@@ -300,6 +300,7 @@ enum_pref_create_widget (GOConfNode *node, GtkWidget *table,
 	g_type_class_unref (enum_class);
 
 	gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (model));
+	g_object_unref (model);
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, TRUE);
 	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
@@ -577,6 +578,7 @@ wordlist_pref_create_widget (GOConfNode *node, GtkWidget *table,
 
 	gtk_tree_view_set_model (GTK_TREE_VIEW (tv),
 				 GTK_TREE_MODEL (model));
+	g_object_unref (model);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (tv),
 				     gtk_tree_view_column_new_with_attributes
 				     (NULL,
@@ -1016,7 +1018,7 @@ pref_tool_page_initializer (PrefState *state,
 				 GO_TYPE_DIRECTION,
 				 (enum_conf_setter_t)gnm_conf_set_core_gui_editing_enter_moves_dir,
 				 (enum_conf_getter_t)gnm_conf_get_core_gui_editing_enter_moves_dir,
-				 _("Enter _Moves Selection"));
+				 _("Enter _Moves Selection"), (char const *(*) (int)) go_direction_get_name);
 	bool_pref_create_widget (gnm_conf_get_core_gui_editing_transitionkeys_node (),
 				 page, row++,
 				 gnm_conf_set_core_gui_editing_transitionkeys,
@@ -1120,7 +1122,7 @@ pref_autocorrect_initialcaps_page_initializer (PrefState *state,
 	wordlist_pref_create_widget (gnm_conf_get_autocorrect_init_caps_list_node (), page,
 				     row++, gnm_conf_set_autocorrect_init_caps_list,
 				     gnm_conf_get_autocorrect_init_caps_list,
-				     "Do _not correct:");
+				     _("Do _not correct:"));
 
 	gtk_widget_show_all (page);
 	return page;
@@ -1147,7 +1149,7 @@ pref_autocorrect_firstletter_page_initializer (PrefState *state,
 	wordlist_pref_create_widget (gnm_conf_get_autocorrect_first_letter_list_node (), page,
 				     row++, gnm_conf_set_autocorrect_first_letter_list,
 				     gnm_conf_get_autocorrect_first_letter_list,
-				     "Do _not capitalize after:");
+				     _("Do _not capitalize after:"));
 
 	gtk_widget_show_all (page);
 	return page;
