@@ -24,7 +24,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  **/
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gnumeric.h>
 #include "dialogs.h"
 #include "help.h"
@@ -36,13 +36,11 @@
 #include <tool-dialogs.h>
 #include <dao-gui-utils.h>
 #include <value.h>
-#include <workbook-edit.h>
+#include <wbc-gtk.h>
 #include <commands.h>
 #include <selection.h>
 
-#include <glade/glade.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtktogglebutton.h>
+#include <gtk/gtk.h>
 #include <widgets/gnumeric-expr-entry.h>
 #include "data-shuffling.h"
 
@@ -106,7 +104,7 @@ shuffle_ok_clicked_cb (G_GNUC_UNUSED GtkWidget *button, ShuffleState *state)
 	input = gnm_expr_entry_parse_as_value (
 		GNM_EXPR_ENTRY (state->input_entry), state->sheet);
 
-	type = gnumeric_glade_group_value (state->gui, shuffle_by);
+	type = gnm_gui_group_value (state->gui, shuffle_by);
 
 	ds = data_shuffling (WORKBOOK_CONTROL (state->wbcg), dao,
 			     state->sheet, input, type);
@@ -127,7 +125,7 @@ shuffle_ok_clicked_cb (G_GNUC_UNUSED GtkWidget *button, ShuffleState *state)
  *
  **/
 void
-dialog_shuffle (WorkbookControlGUI *wbcg)
+dialog_shuffle (WBCGtk *wbcg)
 {
         ShuffleState    *state;
 	WorkbookControl *wbc;
@@ -147,7 +145,7 @@ dialog_shuffle (WorkbookControlGUI *wbcg)
 
 	if (dialog_tool_init (state, wbcg, wb_control_cur_sheet (wbc),
 			      GNUMERIC_HELP_LINK_DATA_SHUFFLE,
-			      "shuffle.glade", "Shuffling",
+			      "shuffle.ui", "Shuffling",
 			      _("Could not create the Data Shuffling dialog."),
 			      SHUFFLE_KEY,
 			      G_CALLBACK (shuffle_ok_clicked_cb), NULL,
@@ -166,7 +164,7 @@ dialog_shuffle (WorkbookControlGUI *wbcg)
 		type = "shuffle_rows";
 	else
 		type = "shuffle_area";
-	w = glade_xml_get_widget (state->gui, type);
+	w = go_gtk_builder_get_widget (state->gui, type);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), TRUE);
 
 	gtk_widget_show (state->dialog);
