@@ -31,6 +31,7 @@
 #include <wbc-gtk.h>
 #include <workbook-priv.h>
 #include <gtk/gtk.h>
+#include <dead-kittens.h>
 
 #define WORKBOOK_ATTRIBUTE_KEY "workbook-attribute-dialog"
 
@@ -164,9 +165,8 @@ attr_dialog_add_item (AttrState *state, char const *page_name,
 	GdkPixbuf * icon = NULL;
 
 	if (icon_name != NULL)
-		icon = gtk_widget_render_icon (state->dialog, icon_name,
-					       GTK_ICON_SIZE_MENU,
-					       WORKBOOK_ATTRIBUTE_KEY);
+		icon = gtk_widget_render_icon_pixbuf (state->dialog, icon_name,
+					       GTK_ICON_SIZE_MENU);
 	if ((parent_path != NULL) && gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (state->store),
 									  &parent, parent_path))
 		gtk_tree_store_append (state->store, &iter, &parent);
@@ -276,6 +276,7 @@ attr_dialog_impl (AttrState *state)
 					   G_TYPE_STRING,
 					   G_TYPE_INT);
 	gtk_tree_view_set_model (state->tview, GTK_TREE_MODEL(state->store));
+	g_object_unref (state->store);
 	selection = gtk_tree_view_get_selection (state->tview);
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
 	column = gtk_tree_view_column_new_with_attributes ("",
