@@ -19,6 +19,7 @@
 #include "libgnumeric.h"
 #include "dialogs.h"
 #include "pixmaps/gnumeric-stock-pixbufs.h"
+#include <dead-kittens.h>
 
 #include <gsf/gsf-impl-utils.h>
 #include <gtk/gtk.h>
@@ -126,7 +127,7 @@ icg_show_gui (IOContextGtk *icg)
 	GtkBox *box;
 	GtkWidget *frame;
 
-	if (init_splash && icg->show_splash){
+	if (init_splash && icg->show_splash) {
 		GdkPixbuf *pixbuf = gdk_pixbuf_new_from_inline
 			(-1, gnumeric_splash, FALSE, NULL);
 		gtk_icon_theme_add_builtin_icon ("GnmSplash",
@@ -136,10 +137,14 @@ icg_show_gui (IOContextGtk *icg)
 	}
 
 	box = GTK_BOX (gtk_vbox_new (FALSE, 0));
-	gtk_box_pack_start (box, gtk_image_new_from_pixbuf (
-		gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
-					  "GnmSplash", 360, 220, NULL)),
-			    TRUE, FALSE, 0);
+	if (icg->show_splash) {
+		GdkPixbuf *pixbuf =
+			gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
+						  "GnmSplash", 360, 220, NULL);
+		gtk_box_pack_start (box, gtk_image_new_from_pixbuf (pixbuf),
+				    TRUE, FALSE, 0);
+		g_object_unref (pixbuf);
+	}
 
 	/* Don't show this unless we need it. */
 	if (icg->files_total > 1) {
@@ -345,7 +350,7 @@ icg_finalize (GObject *obj)
 			G_CALLBACK (cb_icg_window_destroyed), icg);
 		gtk_window_set_focus (icg->window, NULL);
 		gtk_window_set_default (icg->window, NULL);
-		gtk_object_destroy (GTK_OBJECT (icg->window));
+		gtk_widget_destroy (GTK_WIDGET (icg->window));
 	}
 	g_free (icg->progress_msg);
 	icg->window = NULL;
