@@ -76,6 +76,11 @@ struct _GnmParseError {
 	int begin_char, end_char;
 };
 
+typedef struct {
+	gsize start, end;
+	int token;
+} GnmLexerItem;
+
 GnmParseError *parse_error_init (GnmParseError *pe);
 void        parse_error_free (GnmParseError *pe);
 
@@ -90,6 +95,8 @@ typedef enum {
 } GnmExprParseFlags;
 
 struct _GnmConventions {
+	int ref_count;
+
 #if 0
 	/* Not yet.  */
 	gboolean force_absolute_col_references;
@@ -98,6 +105,9 @@ struct _GnmConventions {
 #endif
 	gboolean r1c1_addresses;
 
+	/* Whether function names should be translated.  */
+	gboolean localized_function_names;
+
 	/* Separate elements in lists, 0 will use go_locale. */
 	gunichar arg_sep;
 	/* Separate array columns, 0 will use go_locale. */
@@ -141,11 +151,16 @@ struct _GnmConventions {
 					  GnmConventions const *convs);
 					/* GError **err); */
 
+		/* Called to unescape strings */
+		char const *(*string) (char const *in, GString *target,
+				       GnmConventions const *convs);
+
 		/* Called a lot for anything that might be a function name or
 		 * defined name.  */
 		char const *(*name) (char const *in,
 				     GnmConventions const *convs);
-
+		/* Returns true if a tentative expression name is legal. */
+		gboolean (*name_validate) (const char *name);
 
 		/* Must return non-NULL, and absorb the args, including the list. */
 		GnmExpr const *(*func) (GnmConventions const *convs,
@@ -185,7 +200,10 @@ struct _GnmConventions {
 };
 GnmConventions *gnm_conventions_new	 (void);
 GnmConventions *gnm_conventions_new_full (unsigned size);
-void		gnm_conventions_free	 (GnmConventions *c);
+
+GnmConventions *gnm_conventions_ref	 (GnmConventions *c);
+void		gnm_conventions_unref	 (GnmConventions *c);
+
 
 GNM_VAR_DECL GnmConventions const *gnm_conventions_default;
 GNM_VAR_DECL GnmConventions const *gnm_conventions_xls_r1c1;
@@ -200,6 +218,11 @@ GnmExprTop const *gnm_expr_parse_str (char const *str, GnmParsePos const *pp,
 				      GnmConventions const *convs,
 				      GnmParseError *error);
 
+GnmLexerItem *gnm_expr_lex_all (char const *str, GnmParsePos const *pp,
+				GnmExprParseFlags flags,
+				GnmConventions const *convs);
+
+
 /* Is this string potentially the start of an expression */
 char const *gnm_expr_char_start_p (char const *c);
 
