@@ -25,6 +25,7 @@
 #include "widget-editable-label.h"
 #include <style-color.h>
 #include <gnm-marshalers.h>
+#include <dead-kittens.h>
 
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
@@ -91,12 +92,12 @@ el_set_style_label (EditableLabel *el)
 static void
 el_set_cursor (GtkEntry *entry, GdkCursorType cursor_type)
 {
-	if (entry->text_area) {
+	if (gtk_entry_get_text_area (entry)) {
 		GdkDisplay *display =
 			gtk_widget_get_display (GTK_WIDGET (entry));
 		GdkCursor *cursor =
 			gdk_cursor_new_for_display (display, cursor_type);
-		gdk_window_set_cursor (entry->text_area, cursor);
+		gdk_window_set_cursor (gtk_entry_get_text_area (entry), cursor);
 		gdk_cursor_unref (cursor);
 	}
 }
@@ -152,13 +153,13 @@ el_entry_activate (GtkEntry *entry, G_GNUC_UNUSED gpointer ignored)
 }
 
 static void
-el_destroy (GtkObject *object)
+el_destroy (GtkWidget *widget)
 {
-	EditableLabel *el = EDITABLE_LABEL (object);
+	EditableLabel *el = EDITABLE_LABEL (widget);
 
 	el_cancel_editing (el);
 
-	((GtkObjectClass *)parent_class)->destroy (object);
+	gnm_destroy_class_chain (parent_class, widget);
 }
 
 static gint
@@ -166,8 +167,8 @@ el_button_press_event (GtkWidget *widget, GdkEventButton *button)
 {
 	EditableLabel *el = EDITABLE_LABEL (widget);
 
-	if (button->window != widget->window &&
-	    button->window != el->entry.text_area) {
+	if (button->window != gtk_widget_get_window (widget) &&
+	    button->window != gtk_entry_get_text_area (&el->entry)) {
 		/* Accept the name change */
 		el_entry_activate (GTK_ENTRY (el), NULL);
 		gdk_event_put ((GdkEvent *)button);
@@ -198,7 +199,7 @@ el_key_press_event (GtkWidget *w, GdkEventKey *event)
 	if (el->unedited_text == NULL)
 		return FALSE;
 
-	if (event->keyval == GDK_Escape) {
+	if (event->keyval == GDK_KEY_Escape) {
 		el_cancel_editing (el);
 		return TRUE;
 	}
@@ -231,7 +232,7 @@ el_state_changed (GtkWidget *widget, GtkStateType previous_state)
 {
 	parent_class->state_changed (widget, previous_state);
 	/* GtkEntry::state_changed changes the cursor */
-	if (GTK_WIDGET_REALIZED (widget))
+	if (gtk_widget_get_realized (widget))
 		el_set_cursor (GTK_ENTRY (widget), GDK_HAND2);
 }
 
@@ -252,13 +253,13 @@ el_motion_notify (GtkWidget      *widget,
 }
 
 static void
-el_class_init (GtkObjectClass *object_class)
+el_class_init (GObjectClass *object_class)
 {
 	GtkWidgetClass *widget_class;
 
 	parent_class = g_type_class_peek_parent (object_class);
 
-	object_class->destroy = el_destroy;
+	gnm_destroy_class_set (object_class, el_destroy);
 
 	widget_class = (GtkWidgetClass *) object_class;
 	widget_class->button_press_event  = el_button_press_event;
