@@ -15,6 +15,7 @@
 #include <gnumeric-config.h>
 #include "gnumeric.h"
 #include "workbook-priv.h"
+#include "compilation.h"
 
 #include "workbook-view.h"
 #include "workbook-control.h"
@@ -172,7 +173,7 @@ workbook_init (GObject *object)
 	wb->sheet_hash_private = g_hash_table_new (g_str_hash, g_str_equal);
 	wb->sheet_order_dependents = NULL;
 	wb->sheet_local_functions = NULL;
-	wb->names        = NULL;
+	wb->names = gnm_named_expr_collection_new ();
 
 	/* Nothing to undo or redo */
 	wb->undo_commands = wb->redo_commands = NULL;
@@ -730,7 +731,8 @@ Sheet *
 workbook_sheet_by_index (Workbook const *wb, int i)
 {
 	g_return_val_if_fail (IS_WORKBOOK (wb), NULL);
-	g_return_val_if_fail ((int)wb->sheets->len > i, NULL);
+	g_return_val_if_fail (i < (int)wb->sheets->len, NULL);
+	g_return_val_if_fail (i >= -1, NULL);
 
 	/* i = -1 is special, return NULL */
 
@@ -1330,6 +1332,7 @@ workbook_sheet_state_size (const WorkbookSheetState *wss)
 	return size;
 }
 
+GNM_BEGIN_KILL_SWITCH_WARNING
 char *
 workbook_sheet_state_diff (const WorkbookSheetState *wss_a, const WorkbookSheetState *wss_b)
 {
@@ -1403,21 +1406,15 @@ workbook_sheet_state_diff (const WorkbookSheetState *wss_a, const WorkbookSheetS
 
 	switch (what) {
 	case WSS_SHEET_RENAMED:
-		return (n == 1)
-			? g_strdup (_("Renaming sheet"))
-			: g_strdup_printf (_("Renaming %d sheets"), n);
+		return g_strdup_printf (ngettext ("Renaming sheet", "Renaming %d sheets", n), n);
 	case WSS_SHEET_ADDED:
-		return (n == 1)
-			? g_strdup (_("Adding sheet"))
-			: g_strdup_printf (_("Adding %d sheets"), n);
+		return g_strdup_printf (ngettext ("Adding sheet", "Adding %d sheets", n), n);
 	case WSS_SHEET_ADDED | WSS_SHEET_ORDER:
 		/*
 		 * This is most likely just a sheet inserted, but it just
 		 * might be a compound operation.  Lie.
 		 */
-		return (n == 1)
-			? g_strdup (_("Inserting sheet"))
-			: g_strdup_printf (_("Inserting %d sheets"), n);
+		return g_strdup_printf (ngettext ("Inserting sheet", "Inserting %d sheets", n), n);
 	case WSS_SHEET_TAB_COLOR:
 		return g_strdup (_("Changing sheet tab colors"));
 	case WSS_SHEET_PROPERTIES:
@@ -1428,15 +1425,14 @@ workbook_sheet_state_diff (const WorkbookSheetState *wss_a, const WorkbookSheetS
 		 * This is most likely just a sheet delete, but it just
 		 * might be a compound operation.  Lie.
 		 */
-		return (n == 1)
-			? g_strdup (_("Deleting sheet"))
-			: g_strdup_printf (_("Deleting %d sheets"), n);
+		return g_strdup_printf (ngettext ("Deleting sheet", "Deleting %d sheets", n), n);
 	case WSS_SHEET_ORDER:
 		return g_strdup (_("Changing sheet order"));
 	default:
 		return g_strdup (_("Reorganizing Sheets"));
 	}
 }
+GNM_END_KILL_SWITCH_WARNING
 
 /* ------------------------------------------------------------------------- */
 
